#!python -u

import sys
import argparse

def make_ac_samples():

	parser = argparse.ArgumentParser(description="Create surface samples with adsorption complexes (AC's)", formatter_class=argparse.ArgumentDefaultsHelpFormatter)

	parser.add_argument('--samples-dir','-d', dest='samples_dir', nargs='?', default='tmp',
						help='Directory to be created and populated with AC samples and "interactions" file')

	parser.add_argument('--max-slab-disturbance','-s', dest='max_slab_disturbance', type=float, nargs='?', default=0.1,
						help='Tollerance to difference between empty surface structure and surface structure in AC')

	parser.add_argument('--r-cut-off','-r',  dest = 'r_cut_off', type=float, nargs='?', default=10.,
						help="Suggested cut-off radius of lateral interactions - maximal distance between AC's in generated samples, in Angstroms")

	parser.add_argument('--symmetry-precission','-p', dest='sym_prec', type=float, nargs='?', default=0.9,
						help="Tollerance for detection of AC symmetries")
						
	parser.add_argument('--border-x','-x', dest='border_x', type=int, nargs='?',
						help="Width of border along Ox axis around AC's, in unit cells. If None is specified, then --r-cut-off is used to guess it.")

	parser.add_argument('--border-y','-y', dest='border_y', type=int, nargs='?',
						help="Width of border along Oy axis around AC's, in unit cells. If None is specified, then --r-cut-off is used to guess it.")


	parser.add_argument('empty', metavar='empty-surf-xyz-file',
		               help='Name of the file with empty surface in Extended XYZ format')
	parser.add_argument('ACs', metavar='AC-xyz-file', nargs='+',
		               help='Name of the file with AC in Extended XYZ format')

	args = parser.parse_args()

	ac_fns = [args.empty] + args.ACs

	import susmost

	susmost.make_ac_samples(args.samples_dir, ac_fns, max_slab_disturbance=args.max_slab_disturbance, r_cut_off = args.r_cut_off, max_dimensions=[-1,-1,0], sym_prec=args.sym_prec, borders=[args.border_x, args.border_y])

